#
# spec file for package kexi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soVersion 3.2
%bcond_without lang
Name:           kexi
Version:        3.2.0
Release:        10.1
Summary:        Database Application
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND GFDL-1.2-only
URL:            https://www.kexi-project.org/
Source0:        https://download.kde.org/stable/%{name}/src/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM
Patch0:         Fix-build-with-Qt-5_13.patch
# PATCH-FIX-UPSTREAM
Patch1:         0001-Include-glib.h-outside-of-the-extern-block.patch
# PATCH-FIX-UPSTREAM
Patch2:         Use-plain-Marble-package-instead-of-KexiMarble.patch
BuildRequires:  extra-cmake-modules
BuildRequires:  glib2-devel
# For dir ownership
BuildRequires:  hicolor-icon-theme
BuildRequires:  kdb-devel
BuildRequires:  kf5-filesystem
BuildRequires:  kproperty-devel
BuildRequires:  kreport-devel
BuildRequires:  libmysqld-devel
BuildRequires:  mysql-devel
BuildRequires:  postgresql-server-devel
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5Codecs)
BuildRequires:  cmake(KF5Completion)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5GuiAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5ItemViews)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5TextEditor)
BuildRequires:  cmake(KF5TextWidgets)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5UiTools)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
Requires:       hicolor-icon-theme
Obsoletes:      calligra-kexi < %{version}
Provides:       calligra-kexi = %{version}
# not ported yet
Obsoletes:      calligra-kexi-spreadsheet-import < %{version}
# Kexi needs breeze-icons.rcc during build and on runtime (it doesn't start without it installed)
BuildRequires:  (breeze5-icons-rcc or breeze5-icons < 5.78.0)
Requires:       (breeze5-icons-rcc or breeze5-icons < 5.78.0)

%description
Kexi is a visual database applications creator, competing with
programs like MS Access or Filemaker.

%package spreadsheet-import
Summary:        Spreadsheet-to-Kexi-table import plugin
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Obsoletes:      calligra-kexi-spreadsheet-import < %{version}
Provides:       calligra-kexi-spreadsheet-import = %{version}

%description spreadsheet-import
Kexi is a visual database applications creator, competing with
programs like MS Access or Filemaker.

This package contains a Spreadsheet-to-Kexi-table import plugin.

%lang_package

%prep
%autosetup -p1

%build
# install translations to %%{_kf5_localedir} so they don't clash with the kexi translations in calligra-l10n (KDE4 based)
# can probably be changed back to the standard location when we have calligra 3 in all supported distributions...
%cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir}

%cmake_build

%install
%kf5_makeinstall -C build

%{kf5_find_lang}

# Remove unwanted development files
for i in dataviewcommon formutils extendedwidgets relationsview main migrate utils guiutils datatable core undo
do
    rm %{buildroot}%{_kf5_libdir}/libkexi${i}%{soVersion}.so
done

rm %{buildroot}%{_kf5_libdir}/libkformdesigner%{soVersion}.so

%ldconfig_scriptlets

%files
%license COPYING COPYING.*
%doc AUTHORS README.md
%dir %{_kf5_iconsdir}/hicolor/1024x1024
%dir %{_kf5_iconsdir}/hicolor/1024x1024/apps
%{_kf5_applicationsdir}/org.kde.kexi-%{soVersion}.desktop
%{_kf5_appstreamdir}/org.kde.kexi-%{soVersion}.appdata.xml
%{_kf5_bindir}/kexi-%{soVersion}
%{_kf5_iconsdir}/hicolor/*/*/*
%{_kf5_libdir}/libkexi*.so*
%{_kf5_libdir}/libkformdesigner%{soVersion}.so*
%{_kf5_plugindir}/kexi/
%{_kf5_sharedir}/kexi/

%files lang -f %{name}.lang

%changelog
* Wed Dec 25 2024 Christophe Marin <christophe@krop.fr>
- Stop using the optional marble dependency
* Wed Nov 20 2024 Christophe Marin <christophe@krop.fr>
- Stop using the %%suse_update_desktop_file macro
- Spec cleanup
* Wed Mar 16 2022 Max Lin <mlin@suse.com>
- Use BuildRequires/Requires: breeze5-icons-rcc for Leap 15.4
* Wed Jul 28 2021 Wolfgang Bauer <wbauer@tmo.at>
- Add Use-plain-Marble-package-instead-of-KexiMarble.patch to fix
  build with marble 21.08
* Mon Jun 28 2021 Wolfgang Bauer <wbauer@tmo.at>
- BuildRequire postgresql-server-devel also on Leap 15.2/15.3 to
  fix missing PostgreSQL migration driver
* Mon Jun 28 2021 Christophe Giboudeaux <christophe@krop.fr>
- Remove the optional QtWebKit dependency.
* Wed Apr 28 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with glib >= 2.68
  * 0001-Include-glib.h-outside-of-the-extern-block.patch
* Fri Jan  8 2021 Wolfgang Bauer <wbauer@tmo.at>
- Add dependencies on breeze5-icons-rcc instead of breeze5-icons
  where necessary, kexi needs breeze-icons.rcc (during build and on
  runtime) which has been split out to a seperate package recently
* Tue Sep 29 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Pull in hicolor-icon-theme for dir ownership
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
* Mon Aug 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add Fix-build-with-Qt-5_13.patch
* Thu Apr 11 2019 wbauer@tmo.at
- Update to 3.2.0
  * Bug fixes
    + Add protection against invalid translation of widget names
    + Startup: Improve display of tried locations for resources
    lookup and lookup algorithm (kde#391810)
    + Startup: Add missing translations for "Could not open icon
    resource file" messages
    + General: Make certain views work in User mode (kde#396875)
    + General: Add "All files" filter to file widgets for
    non-Plasma systems
    + General: Welcome page: Always display the project file names
    in addition to captions
    + General: Welcome page: Add long localized last opening date
    to project tool tips
    + General: Welcome page: Show recent project files that start
    with "." / hidden files
    + Table View: Make zero values displayed for integer columns
    (kde#395189)
    + Table View: Fix validation of values in default input box of
    table view (kde#395225)
    + Table and Form View: Fix two-digit year formats issue: do
    not allow by default (kde#378481)
  * Years are 4 digits now in tables and forms. On the output
    INFO message says as explained at
    https://bugs.kde.org/show_bug.cgi?id=378481#c5. Data entry
    works based on this new year format. Changes are properly
    saved to db. Display output e.g. in queries and reports
    follow this format too.
  * Set AllowTwoDigitYearFormats=true in kexirc, [General]
    section to force using 2 digits.
    + Queries: Fix crash on failed opening of query in Design view
    + Forms: Fix crash when right-clicking in form data view on
    widget such as text box (kde#402923)
    + Reports: Fix crash in data fetching and aggregation scripts
    in reports (kde#392753)
    + Reports: Support params in report queries. KEXI now prompts
    for parameters in queries that use them. (kde#379694)
    + Import: Fix translation issue in the Database Importing
    Assistant (kde#399296)
    + Import: Skip table name if physical table is non-existing,
    use the new tableNames API in migration (kde#392112)
    + MS Access import
  * Fix crash on importing zero-length memo data (long text)
  * Fix not being able to handle binary objects larger than
    16 MiB. Limit is now 256 MiB.
  * Fix possible crash when importing MDB file having non-latin
    characters in column names of unexpected length
    (kde#396984)
    + Export: Fix crash on exporting tabular data to clipboard
    (introduced in 3.1.0) (kde#394519)
    + Export: Fix filename selection for export dialogs and allow
    to pre-select filename in file dialogs
  * Improvements
    + Assistants: properly focus input boxes after moving to other
    page, make Alt+arrows work for Back/Next, make Enter accept
    page if applicable
    + Project type selection in the new project assistant: do not
    assume user clicked the type button but just focused it
    + Improve display of Finish buttons of CSV export/import
    dialogs
    + New / Import project assistants
  * Destination file requester is now of Save type
  * Use Documents location if there are no recent dirs known
    yet
  * Better preserve path while updating filename based on
    project caption
  * Buildsystem
    + Install the application icons
    + Create (and install) rcc files with kexi icons in
    co-installable dirs
    + Fix build with Qt 5.11 (missing headers)
    + Fix build with Qt 5.6
    + Fix data install dir for Windows, make icons installed
    relative to that
    + Make appdata.xml, app icons and kexi.desktop co-installable
    + Make KEXI compile for MOBILE productset
    + Win/Mac: still install copied KEXI files but add the original
    ones to the binary because the copied ones do not exist yet
    before ecm_add_app_icon() gets called
    + CMake: find PostgreSQL 11
- Drop patches merged upstream:
  * Install-the-application-icons.patch
  * fix-build-with-qt5.6.patch
  * Fix-build-with-Qt-511.patch
- Use %%kf5_find_lang macro to generate the lang package filelist
- BuildRequire postgresql-server-devel instead of postgresql-devel
  on Tumbleweed to fix building the PostgreSQL migration driver
- Run spec-cleaner
* Sun Jun  3 2018 christophe@krop.fr
- Add Fix-build-with-Qt-511.patch
- Run spec-cleaner
* Tue Mar 20 2018 wbauer@tmo.at
- Update to 3.1.0:
  * General
    + Bump soname for the libraries to separate from incompatible
    3.0.x versions
  * New features
    + Add social buttons to Kexi menu
    + Make KEXI examples be built and installed by default as it's
    likely expected by users
    + Add support for setting character encoding for source
    database to Import Table Assistant
  * Bug fixes
    + Fix location of example dir
    + Mark and install Kexi example file as read-only on all
    platforms
    + Fix crash when global search box is used after re-opening
    another project
    + Add MainWindow/GlobalSearchBoxEnabled (bool) option that
    controls display of the global search box (kde#390794)
    + Disable compacting action if project is not open as we do not
    support this case for now
    + Do not display "clear" icons in read-only line edits of
    Database connection widget
    + Import table assistant: allow to move back and change source
    connection, react on double clicking
    + Do not display empty message when starting without plugins,
    inform users about the status (kde#389844)
    + Do not disable contents of "Your contributions" page (part of
    the Welcome page)
    + CSV import assistant: switch back to checkboxes from command
    link buttons
    + CSV import assistant: fix layout of delimiter widget
    + CSV import assistant: Improve getting filename selection from
    the new file requester
    + CSV import assistant: Single click on file requester's item
    moves to next page
    + Fix broken CSV import (kde#386102)
    + Rework the KexiFileRequester to use a simple and light
    QTreeView
    + Update mime types info when needed
    + Fix "wait" cursors
    + Fix crash when deleting or renaming a table (kde#379078)
    + Table Designer: don't warn about non-existing table or query
    when lookup fields are cleared
    + Table view's combo box editor: delete the combo button when
    needed, this fixes possible crash when user clicks the
    non-deleted button
    + Fix possible crash when table view containing combo boxes is
    re-used (kde#389029)
    + Fix recent dirs handling for file widgets (bug from Kexi
    3.0.x), move recent start/recent dirs handling to KexiUtils
    + Forms: Fix double moving forward/backward on tab/backtab key
    press
    + Before physical altering or deleting table ask the user to
    close depending table/query/report/form (kde#371896)
    + Queries: Synchronize the "dirty" flag between Design and Text
    views
    + SQL designer: remove possible memory leak if the parsed query
    object is still present on destruction
    + Queries: fix possible crash in data view when the query
    design changes in a design view
    + Queries: after parsing the SQL only assume the query changed
    if the SQL differs from the previous SQL
    + Fix memory leak in Project data object (list of auto-open
    objects)
    + Fix detection of single-click mode for XFCE
    + Reports: Make jumping to specific page possible
    + Reports: Keep information about type of data source (table or
    query). Detects if needed. (kde#385071)
  * Optimizations
    + Improve memory management of raw SQL execution and preparing
  * Improvements
    + Set Cancel as default for critical question message boxes
    + Use Delete verb rather than Remove for consistency
    + Don't use empty space by object tabs (like in web browsers)
    + Backport experimental scripting in Kexi
    + Add config file setting to force the use of KFileWidgets or
    simple file requesters independently of the desktop
    + Detect whether native operating system's dialogs should be
    used
    + Query Designer: Improve "The query you entered is incorrect.
    Do you want to cancel any changes made to this SQL text?"
    question
    + Query Designer: Improve "Do you want to save invalid query?"
    question
    + Import Table assistant: improve appearance of the "Finish"
    page and logic for buttons
    + Project Import assistant: support single-click accepting of
    source databases if needed
    + Translations and typo fixes
    + Add option to build without KFileWidget, default on Windows
    + Connection selector widget: select Next step on double click,
    don't select on highlighting
    + Add location edit and file filter combo work in
    KexiFileRequester, add filename completion
    + Reports: Remove traces of "external data" support, this is
    not supported since Kexi 2.3
    + Reports: Remove no longer necessary "Set Data" button from
    the data source tab
  * Docs and examples
    + Fix and update Simple_Database.kexi example
- Add Install-the-application-icons.patch from upstream, this makes
  it unnecessary to manually copy an application icon to the
  hicolor theme in %%install
- Add fix-build-with-qt5.6.patch to make it compile on Leap 42
* Sat Aug 12 2017 wbauer@tmo.at
- Update to 3.0.2:
  * General
  - Don't move to first Project navigator's item when last object
    tab is closed (usability fix)
  - Improve detection of desktop type and use it in file dialogs
    and the Feedback Agent
  - Detect single click setting for XFCE
  - Fix appearance of Kexi tabbed toolbar for gtk2 style used by
    XFCE
  - Make auto-opening command line options work for Kexi again
    (kde#378418)
  - Fix regression since 3.0.0: store, copy and update user
    settings for objects, e.g. column widths
  - Fix regression since 3.0.0: Keep compatibility with older
    format versions regarding the storage for object type
  - Fix regression since 3.0.0: Allow to change name and caption
    of objects (kde#379078)
  - Close window before renaming object on user's request
  - Fix background of the Kexi button for fusion style
  - Fix vertical alignment of the record navigator (kde#379844)
  - Return invalid URL when open/save image dialog was canceled
  - Improve image chooser for properties of type Pixmap: display
    "all supported files" (kde#379073)
  * Table Designer
  * Query Designer
  - Improve WHERE conditions handling in query designer
    (kde#377579)
  - Fix updating SQL statement in SQL designer after switching
    from other views and property revert to previous SQL
    (kde#377579)
  * Form Designer
  - Make check boxes two-state by default because this covers 99%%
    of use cases. It is also Qt's default.
  - Don't set any special minimum size for checkbox form widgets,
    users may want to set specific small size
  - Fix geometry of the combo box (kde#265330)
  - Make it possible to use vertical alignment property in Text
    Box form widgets
  - Fix possible crashes in form's undo/redo actions, make them
    properly work with alignment properties of widgets
    (kde#380175)
  * Report Designer
  - Improve WHERE conditions handling in report designer
    (kde#377579)
  - Hide GUI actions for not implemented export to ODF Text and
    Spreadsheet formats
  * Buildsystem
  - Fix build for macOS (kde#377662)
  - Detect PostgreSQL 10
  * Tests
  - Search for resource file in bin/data also on non-Windows so
    tests work OK without installation of the project
* Tue Apr  4 2017 wbauer@tmo.at
- Update to 3.0.1.1:
  * General
  - Make project navigator's "single click" mode work on Windows
  - Use the only supported style (breeze) on Windows and Mac
  - Make the Status Bar not using KIO copy on Windows (to
    simplify the runtime)
  - Fix memory leaks related to project migration
  - Limit size of application icon on Mac
  * Table Designer
  - Fix altering physical table design when lookup fields are in
    use (kde#371958)
  * Query Designer
  - Fix adding table relationships in Query Designer using
    drag&drop (regression since 3.0) (kde#376970)
  * Form Designer
  - Update button form widget icon (32px)
  - Add breeze icons for combobox form widget
  - Add breeze icons for frame form widget
  - Add breeze icons for tab widget and page
  - Add breeze icons for groupbox widget
  - Add breeze icons for data source tag
  - Fix handling mouse release in forms
  * Buildsystem
  - Make it possible to find PostgreSQL 9.6
  - Improve icons lookup when Kexi is run without installing
  - Improve searching for the MySQL migration build dependencies
  - Keep apps in the same bin dir so resources that are kept
    relative to this dir can be found without installing
* Tue Jan 24 2017 jengelh@inai.de
- Update description
* Mon Jan 23 2017 wbauer@tmo.at
- also install the AUTHORS, README.md and COPYING files
- use "%%post(un) -p /sbin/ldconfig"
* Wed Jan 11 2017 wbauer@tmo.at
- initial package based on version 3.0.0
